@@ -221,11 +221,6 @@ void	R_AddDrawViewCmd( viewDef_t *parms ) {
 
 	cmd->viewDef = parms;
 
-	if ( parms->viewEntitys ) {
-		// save the command for r_lockSurfaces debugging
-		tr.lockSurfacesCmd = *cmd;
-	}
-
 	tr.pc.c_numViews++;
 
 	R_ViewStatistics( parms );
@@ -235,43 +230,6 @@ void	R_AddDrawViewCmd( viewDef_t *parms ) {
 //=================================================================================
 
 
-/*
-======================
-R_LockSurfaceScene
-
-r_lockSurfaces allows a developer to move around
-without changing the composition of the scene, including
-culling.  The only thing that is modified is the
-view position and axis, no front end work is done at all
-
-
-Add the stored off command again, so the new rendering will use EXACTLY
-the same surfaces, including all the culling, even though the transformation
-matricies have been changed.  This allow the culling tightness to be
-evaluated interactively.
-======================
-*/
-void R_LockSurfaceScene( viewDef_t *parms ) {
-	drawSurfsCommand_t	*cmd;
-	viewEntity_t			*vModel;
-
-	// set the matrix for world space to eye space
-	R_SetViewMatrix( parms );
-	tr.lockSurfacesCmd.viewDef->worldSpace = parms->worldSpace;
-
-	// update the view origin and axis, and all
-	// the entity matricies
-	for( vModel = tr.lockSurfacesCmd.viewDef->viewEntitys ; vModel ; vModel = vModel->next ) {
-		myGlMultMatrix( vModel->modelMatrix,
-			tr.lockSurfacesCmd.viewDef->worldSpace.modelViewMatrix,
-			vModel->modelViewMatrix );
-	}
-
-	// add the stored off surface commands again
-	cmd = (drawSurfsCommand_t *)R_GetCommandBuffer( sizeof( *cmd ) );
-	*cmd = tr.lockSurfacesCmd;
-}
-
 /*
 =============
 R_CheckCvars
@@ -288,6 +246,20 @@ static void R_CheckCvars( void ) {
 		r_brightness.ClearModified();
 		R_SetColorMappings();
 	}
+
+	if ( r_gammaInShader.IsModified() ) {
+		r_gammaInShader.ClearModified();
+		// reload shaders so they either add or remove the code for setting gamma/brightness in shader
+		R_ReloadARBPrograms_f( idCmdArgs() );
+
+		if ( r_gammaInShader.GetBool() ) {
+			common->Printf( "Will apply r_gamma and r_brightness in shaders\n" );
+			GLimp_ResetGamma(); // reset hardware gamma
+		} else {
+			common->Printf( "Will apply r_gamma and r_brightness in hardware (possibly on all screens)\n" );
+			R_SetColorMappings();
+		}
+	}
 }
 
 /*
@@ -599,6 +571,18 @@ void idRenderSystemLocal::BeginFrame( int windowWidth, int windowHeight ) {
 		return;
 	}
 
+	// DG: r_lockSurfaces only works properly if r_useScissor is disabled
+	if ( r_lockSurfaces.IsModified() ) {
+		static bool origUseScissor = true;
+		r_lockSurfaces.ClearModified();
+		if ( r_lockSurfaces.GetBool() ) {
+			origUseScissor = r_useScissor.GetBool();
+			r_useScissor.SetBool( false );
+		} else {
+			r_useScissor.SetBool( origUseScissor );
+		}
+	} // DG end
+
 	// determine which back end we will use
 	SetBackEndRenderer();
 
@@ -715,6 +699,7 @@ void idRenderSystemLocal::EndFrame( int *frontEndMsec, int *backEndMsec ) {
 
 	// use the other buffers next frame, because another CPU
 	// may still be rendering into the current buffers
+
 	R_ToggleSmpFrame();
 
 	// we can now release the vertexes used this frame
