@@ -179,12 +179,14 @@ void idSoundChannel::Clear( void ) {
 	diversity = 0.0f;
 	leadinSample = NULL;
 	trigger44kHzTime = 0;
+	stopped = false;
 	for( j = 0; j < 6; j++ ) {
 		lastV[j] = 0.0f;
 	}
 	memset( &parms, 0, sizeof(parms) );
 
 	triggered = false;
+	paused = false;
 	openalSource = 0;
 	openalStreamingOffset = 0;
 	openalStreamingBuffer[0] = openalStreamingBuffer[1] = openalStreamingBuffer[2] = 0;
@@ -210,6 +212,7 @@ idSoundChannel::Stop
 */
 void idSoundChannel::Stop( void ) {
 	triggerState = false;
+	stopped = true;
 	if ( decoder != NULL ) {
 		idSampleDecoder::Free( decoder );
 		decoder = NULL;
@@ -225,6 +228,9 @@ void idSoundChannel::ALStop( void ) {
 	if ( alIsSource( openalSource ) ) {
 		alSourceStop( openalSource );
 		alSourcei( openalSource, AL_BUFFER, 0 );
+		// unassociate effect slot from source, so the effect slot can be deleted on shutdown
+		// even though the source itself is deleted later (in idSoundSystemLocal::Shutdown())
+		alSource3i( openalSource, AL_AUXILIARY_SEND_FILTER, AL_EFFECTSLOT_NULL, 0, AL_FILTER_NULL );
 		soundSystemLocal.FreeOpenALSource( openalSource );
 	}
 
@@ -461,9 +467,8 @@ void idSoundEmitterLocal::CheckForCompletion( int current44kHzTime ) {
 						if ( chan->leadinSample->onDemand ) {
 							chan->leadinSample->PurgeSoundSample();
 						}
-						continue;
 					}
-				} else if ( ( chan->trigger44kHzTime + chan->leadinSample->LengthIn44kHzSamples() < current44kHzTime ) || ( state == AL_STOPPED ) ) {
+				} else if ( ( chan->trigger44kHzTime + chan->leadinSample->LengthIn44kHzSamples() < current44kHzTime ) || ( chan->stopped ) ) {
 					chan->Stop();
 
 					// free hardware resources
@@ -473,7 +478,6 @@ void idSoundEmitterLocal::CheckForCompletion( int current44kHzTime ) {
 					if ( chan->leadinSample->onDemand ) {
 						chan->leadinSample->PurgeSoundSample();
 					}
-					continue;
 				}
 			}
 
@@ -831,6 +835,7 @@ int idSoundEmitterLocal::StartSound( const idSoundShader *shader, const s_channe
 	chan->triggerGame44kHzTime = soundWorld->game44kHz;
 	chan->soundShader = shader;
 	chan->triggerChannel = channel;
+	chan->stopped = false;
 	chan->Start();
 
 	// we need to start updating the def and mixing it in
@@ -958,6 +963,49 @@ void idSoundEmitterLocal::StopSound( const s_channelType channel ) {
 	Sys_LeaveCriticalSection();
 }
 
+// DG: to pause active OpenAL sources when entering menu etc
+void idSoundEmitterLocal::PauseAll( void ) {
+
+	Sys_EnterCriticalSection();
+
+	for( int i = 0; i < SOUND_MAX_CHANNELS; i++ ) {
+		idSoundChannel	*chan = &channels[i];
+
+		if ( !chan->triggerState ) {
+			continue;
+		}
+
+		if ( alIsSource( chan->openalSource ) ) {
+			alSourcePause( chan->openalSource );
+			chan->paused = true;
+		}
+	}
+
+	Sys_LeaveCriticalSection();
+}
+
+
+// DG: to resume active OpenAL sources when leaving menu etc
+void idSoundEmitterLocal::UnPauseAll( void ) {
+
+	Sys_EnterCriticalSection();
+
+	for( int i = 0; i < SOUND_MAX_CHANNELS; i++ ) {
+		idSoundChannel	*chan = &channels[i];
+
+		if ( !chan->triggerState ) {
+			continue;
+		}
+
+		if ( alIsSource( chan->openalSource ) && chan->paused ) {
+			alSourcePlay( chan->openalSource );
+			chan->paused = false;
+		}
+	}
+
+	Sys_LeaveCriticalSection();
+}
+
 /*
 ===================
 idSoundEmitterLocal::FadeSound
