@@ -93,6 +93,9 @@ void idSoundWorldLocal::Init( idRenderWorld *renderWorld ) {
 				// pow(10.0, (-1150*1.5)/2000.0)
 				soundSystemLocal.alFilterf(listenerFilters[1], AL_LOWPASS_GAINHF, 0.137246f);
 			}
+			// allow reducing the gain effect globally via s_alReverbGain CVar
+			listenerSlotReverbGain = soundSystemLocal.s_alReverbGain.GetFloat();
+			soundSystemLocal.alAuxiliaryEffectSlotf(listenerSlot, AL_EFFECTSLOT_GAIN, listenerSlotReverbGain);
 		}
 	}
 
@@ -127,7 +130,10 @@ idSoundWorldLocal::idSoundWorldLocal
 ===============
 */
 idSoundWorldLocal::idSoundWorldLocal() {
+	listenerEffect                = 0;
+	listenerSlot                  = 0;
 	listenerAreFiltersInitialized = false;
+	listenerSlotReverbGain = 1.0f;
 }
 
 /*
@@ -155,6 +161,15 @@ void idSoundWorldLocal::Shutdown() {
 
 	AVIClose();
 
+	// delete emitters before deletign the listenerSlot, so their sources aren't
+	// associated with the listenerSlot anymore
+	for ( i = 0; i < emitters.Num(); i++ ) {
+		if ( emitters[i] ) {
+			delete emitters[i];
+			emitters[i] = NULL;
+		}
+	}
+
 	if (idSoundSystemLocal::useEFXReverb) {
 		if (soundSystemLocal.alIsAuxiliaryEffectSlot(listenerSlot)) {
 			soundSystemLocal.alAuxiliaryEffectSloti(listenerSlot, AL_EFFECTSLOT_EFFECT, AL_EFFECTSLOT_NULL);
@@ -171,14 +186,9 @@ void idSoundWorldLocal::Shutdown() {
 				listenerFilters[1] = AL_FILTER_NULL;
 			}
 		}
+		listenerSlotReverbGain = 1.0f;
 	}
 
-	for ( i = 0; i < emitters.Num(); i++ ) {
-		if ( emitters[i] ) {
-			delete emitters[i];
-			emitters[i] = NULL;
-		}
-	}
 	localSound = NULL;
 }
 
@@ -519,6 +529,13 @@ void idSoundWorldLocal::MixLoop( int current44kHz, int numSpeakers, float *final
 		ALuint effect = 0;
 		idStr s(listenerArea);
 
+		// allow reducing the gain effect globally via s_alReverbGain CVar
+		float gain = soundSystemLocal.s_alReverbGain.GetFloat();
+		if (listenerSlotReverbGain != gain) {
+			listenerSlotReverbGain = gain;
+			soundSystemLocal.alAuxiliaryEffectSlotf(listenerSlot, AL_EFFECTSLOT_GAIN, gain);
+		}
+
 		bool found = soundSystemLocal.EFXDatabase.FindEffect(s, &effect);
 		if (!found) {
 			s = listenerAreaName;
@@ -1366,6 +1383,11 @@ void idSoundWorldLocal::ReadFromSaveGame( idFile *savefile ) {
 			// make sure we start up the hardware voice if needed
 			chan->triggered = chan->triggerState;
 			chan->openalStreamingOffset = currentSoundTime - chan->trigger44kHzTime;
+			// DG: round up openalStreamingOffset to multiple of 8, so it still has an even number
+			//  if we calculate "how many 11kHz stereo samples do we need to decode" and don't
+			//  run into a "I need one more sample apparently, so decode 0 stereo samples"
+			//  situation that could cause an endless loop.. (44kHz/11kHz = 4; *2 for stereo => 8)
+			chan->openalStreamingOffset = (chan->openalStreamingOffset+7) & ~7;
 
 			// adjust the hardware fade time
 			if ( chan->channelFade.fadeStart44kHz != 0 ) {
@@ -1477,6 +1499,16 @@ void idSoundWorldLocal::Pause( void ) {
 	}
 
 	pause44kHz = soundSystemLocal.GetCurrent44kHzTime();
+
+	for ( int i = 0; i < emitters.Num(); i++ ) {
+		idSoundEmitterLocal * emitter = emitters[i];
+
+		// if no channels are active, do nothing
+		if ( emitter == NULL || !emitter->playing ) {
+			continue;
+		}
+		emitter->PauseAll();
+	}
 }
 
 /*
@@ -1496,6 +1528,16 @@ void idSoundWorldLocal::UnPause( void ) {
 	OffsetSoundTime( offset44kHz );
 
 	pause44kHz = -1;
+
+	for ( int i = 0; i < emitters.Num(); i++ ) {
+		idSoundEmitterLocal * emitter = emitters[i];
+
+		// if no channels are active, do nothing
+		if ( emitter == NULL || !emitter->playing ) {
+			continue;
+		}
+		emitter->UnPauseAll();
+	}
 }
 
 /*
