@@ -40,7 +40,7 @@ If you have questions concerning this license or the applicable additional terms
 ===============================================================================
 */
 
-// Win32
+// AROS
 #if defined(__AROS__)
 
 #define _alloca						alloca
@@ -200,6 +200,18 @@ If you have questions concerning this license or the applicable additional terms
 #undef FindText								// stupid namespace poluting Microsoft monkeys
 #endif
 
+// Apple legacy
+#ifdef __APPLE__
+#include <Availability.h>
+#ifdef __MAC_OS_X_VERSION_MIN_REQUIRED
+#if __MAC_OS_X_VERSION_MIN_REQUIRED == 1040
+#define OSX_TIGER
+#elif __MAC_OS_X_VERSION_MIN_REQUIRED < 1060
+#define OSX_LEOPARD
+#endif
+#endif
+#endif
+
 #define ID_TIME_T time_t
 
 typedef unsigned char			byte;		// 8 bits
