@@ -225,7 +225,8 @@ void codec::Segment( int *alist, float *flist, int numElements, float rmse)
 				fy = RMULT*(float)(codebook2[onf][numc+0]) +
 						GMULT*(float)(codebook2[onf][numc+1]) +
 							BMULT*(float)(codebook2[onf][numc+2]) + 0.5f;
-				 if (fy<0) fy = 0; if (fy>255) fy = 255;
+				if (fy<0) fy = 0;
+				if (fy>255) fy = 255;
 
 				fcr += RIEMULT*(float)(codebook2[onf][numc+0]);
 				fcr += GIEMULT*(float)(codebook2[onf][numc+1]);
@@ -322,7 +323,7 @@ void codec::Segment( int *alist, float *flist, int numElements, float rmse)
 int	codec::BestCodeword( unsigned char *tempvector, int dimension, VQDATA **codebook )
 {
 	VQDATA dist;
-	VQDATA bestDist = HUGE_VAL;
+	VQDATA bestDist = idMath::INFINITY;
 	VQDATA tempvq[64];
 	int bestIndex = -1;
 
@@ -1319,7 +1320,9 @@ byte *idataA, *idataB;
 		j = 0;
 		for( i=0; i<numQuadCels; i++ ) {
 			if (qStatus[i].size == 8 && qStatus[i].status) {
-				if (qStatus[i].status < DEAD) num[qStatus[i].status]++; j++;
+				if (qStatus[i].status < DEAD)
+					num[qStatus[i].status]++;
+				j++;
 			}
 		}
 		common->Printf("sparseEncode: for 08x08 CCC = %d, FCC = %d, MOT = %d, SLD = %d, PAT = %d\n", num[CCC], num[FCC], num[MOT], num[SLD], num[PAT]);
@@ -1327,7 +1330,9 @@ byte *idataA, *idataB;
 		for(i=0;i<DEAD;i++) num[i] = 0;
 		for( i=0; i<numQuadCels; i++ ) {
 			if (qStatus[i].size == 4 && qStatus[i].status) {
-				if (qStatus[i].status < DEAD) num[qStatus[i].status]++; j++;
+				if (qStatus[i].status < DEAD)
+					num[qStatus[i].status]++;
+				j++;
 			}
 		}
 		common->Printf("sparseEncode: for 04x04 CCC = %d, FCC = %d, MOT = %d, SLD = %d, PAT = %d\n", num[CCC], num[FCC], num[MOT], num[SLD], num[PAT]);
@@ -1420,7 +1425,9 @@ byte *idataA, *idataB;
 		j = 0;
 		for( i=0; i<numQuadCels; i++ ) {
 			if (qStatus[i].size == 8 && qStatus[i].status) {
-				if (qStatus[i].status < DEAD) num[qStatus[i].status]++; j++;
+				if (qStatus[i].status < DEAD)
+					num[qStatus[i].status]++;
+				j++;
 			}
 		}
 		common->Printf("sparseEncode: for 08x08 CCC = %d, FCC = %d, MOT = %d, SLD = %d, PAT = %d\n", num[CCC], num[FCC], num[MOT], num[SLD], num[PAT]);
@@ -1428,7 +1435,9 @@ byte *idataA, *idataB;
 		for(i=0;i<DEAD;i++) num[i] = 0;
 		for( i=0; i<numQuadCels; i++ ) {
 			if (qStatus[i].size == 4 && qStatus[i].status) {
-				if (qStatus[i].status < DEAD) num[qStatus[i].status]++; j++;
+				if (qStatus[i].status < DEAD)
+					num[qStatus[i].status]++;
+				j++;
 			}
 		}
 		common->Printf("sparseEncode: for 04x04 CCC = %d, FCC = %d, MOT = %d, SLD = %d, PAT = %d\n", num[CCC], num[FCC], num[MOT], num[SLD], num[PAT]);
@@ -1505,7 +1514,7 @@ void codec::VQ( const int numEntries, const int dimension, const unsigned char *
 		//
 		// find the closest two and eliminate one
 		//
-		double bestDist = HUGE_VAL;
+		double bestDist = idMath::INFINITY;
 		double dist, simport;
 		int bestIndex = -1;
 		int bestOtherIndex = 0;
@@ -1571,7 +1580,7 @@ void codec::VQ( const int numEntries, const int dimension, const unsigned char *
 		// until we have reduced it to 256 entries, find one to toss
 		//
 		do {
-			bestDist = HUGE_VAL;
+			bestDist = idMath::INFINITY;
 			bestIndex = -1;
 			bestOtherIndex = -1;
 			if (optimize) {
@@ -1586,7 +1595,7 @@ void codec::VQ( const int numEntries, const int dimension, const unsigned char *
 				}
 			}
 			if (bestIndex == -1 || !optimize) {
-				bestDist = HUGE_VAL;
+				bestDist = idMath::INFINITY;
 				bestIndex = -1;
 				bestOtherIndex = 0;
 				aentries = 0;
